@@ -1,4 +1,4 @@
-/*      $Id: menu.c 28351 2008-10-21 21:23:05Z olivier $
+/*      $Id: menu.c 27421 2008-08-04 20:28:44Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -12,15 +12,17 @@
 
         You should have received a copy of the GNU General Public License
         along with this program; if not, write to the Free Software
-        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+        Foundation, Inc., Inc., 51 Franklin Street, Fifth Floor, Boston,
+        MA 02110-1301, USA.
+
 
         Metacity - (c) 2001 Havoc Pennington
-        xfwm4    - (c) 2002-2006 Olivier Fourdan
+        xfwm4    - (c) 2002-2008 Olivier Fourdan
 
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include <X11/Xlib.h>
@@ -33,23 +35,30 @@
 #include <libxfce4util/libxfce4util.h>
 
 #include "event_filter.h"
-#include "misc.h"
 #include "menu.h"
+#include "misc.h"
 
 static GtkWidget *menu_open = NULL;
 static MenuItem menuitems[] = {
     {MENU_OP_MAXIMIZE, "gtk-zoom-100", N_("Ma_ximize")},
-    {MENU_OP_UNMAXIMIZE, "gtk-zoom-out", N_("Un_maximize")},
-    {MENU_OP_MINIMIZE, "gtk-undo", N_("_Hide")},
+    {MENU_OP_UNMAXIMIZE, "gtk-zoom-out", N_("(Un)Ma_ximize")},
+    {MENU_OP_MINIMIZE, "gtk-undo", N_("Mi_nimize")},
     {MENU_OP_MINIMIZE_ALL, "gtk-clear", N_("Hide _all others")},
     {MENU_OP_UNMINIMIZE, "gtk-add", N_("S_how")},
+    {MENU_OP_MOVE, NULL, N_("_Move")},
+    {MENU_OP_RESIZE, NULL, N_("_Resize")},
+    {0, NULL, NULL},
     {MENU_OP_SHADE, "gtk-goto-top", N_("_Shade")},
-    {MENU_OP_UNSHADE, "gtk-goto-bottom", N_("Un_shade")},
+    {MENU_OP_UNSHADE, "gtk-goto-bottom", N_("(Un)_Shade")},
     {MENU_OP_STICK, "gtk-add", N_("S_tick")},
-    {MENU_OP_UNSTICK, "gtk-remove", N_("Uns_tick")},
+    {MENU_OP_UNSTICK, "gtk-remove", N_("(Un)S_tick")},
     {MENU_OP_CONTEXT_HELP, "gtk-help", N_("Context _help")},
-    {MENU_OP_ABOVE, NULL, N_("Always on top")},
-    {MENU_OP_NORMAL, "gtk-apply", N_("Always on top")},
+    {0, NULL, NULL},
+    {MENU_OP_ABOVE, "gtk-go-up", N_("Above")},
+    {MENU_OP_NORMAL, "gtk-go-forward", N_("Normal")},
+    {MENU_OP_BELOW, "gtk-go-down", N_("Below")},
+    {MENU_OP_FULLSCREEN, "gtk-fullscreen", N_("_Fullscreen")},
+    {MENU_OP_UNFULLSCREEN, "gtk-fullscreen", N_("(Un)_Fullscreen")},
     {MENU_OP_WORKSPACES, NULL, N_("Send to...")},
     {0, NULL, NULL},
     {MENU_OP_DELETE, "gtk-close", N_("_Close")},
