@@ -1,4 +1,4 @@
-/*      $Id: netwm.c 27356 2008-07-20 21:22:15Z olivier $
+/*      $Id: netwm.c 27995 2008-09-30 16:37:35Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -44,6 +44,7 @@
 #include "netwm.h"
 #include "screen.h"
 #include "stacking.h"
+#include "terminate.h"
 #include "transients.h"
 #include "workspaces.h"
 
@@ -88,7 +89,7 @@ clientSetNetState (Client * c)
         TRACE ("clientSetNetState : skip_taskbar");
         data[i++] = display_info->atoms[NET_WM_STATE_SKIP_TASKBAR];
     }
-    if (FLAG_TEST (c->flags, CLIENT_FLAG_MAXIMIZED))
+    if (FLAG_TEST_ALL (c->flags, CLIENT_FLAG_MAXIMIZED))
     {
         TRACE ("clientSetNetState : maximize vert + horiz");
         data[i++] = display_info->atoms[NET_WM_STATE_MAXIMIZED_HORZ];
@@ -399,20 +400,20 @@ clientUpdateNetState (Client * c, XClientMessageEvent * ev)
         if ((action == NET_WM_STATE_ADD) && !FLAG_TEST (c->flags, CLIENT_FLAG_STATE_MODAL))
         {
             FLAG_SET (c->flags, CLIENT_FLAG_STATE_MODAL);
-            clientSetNetState (c);
             clientWindowType (c);
+            clientSetNetState (c);
         }
         else if ((action == NET_WM_STATE_REMOVE) && FLAG_TEST (c->flags, CLIENT_FLAG_STATE_MODAL))
         {
             FLAG_UNSET (c->flags, CLIENT_FLAG_STATE_MODAL);
-            clientSetNetState (c);
             clientWindowType (c);
+            clientSetNetState (c);
         }
         else if (action == NET_WM_STATE_TOGGLE)
         {
             FLAG_TOGGLE (c->flags, CLIENT_FLAG_STATE_MODAL);
-            clientSetNetState (c);
             clientWindowType (c);
+            clientSetNetState (c);
         }
         frameQueueDraw (c, TRUE);
     }
@@ -733,7 +734,6 @@ clientUpdateFullscreenState (Client * c)
         wc.height = c->fullscreen_old_height;
         layer = c->fullscreen_old_layer;
     }
-    clientSetNetState (c);
     if (FLAG_TEST (c->xfwm_flags, XFWM_FLAG_MANAGED))
     {
         clientConfigure (c, &wc, CWX | CWY | CWWidth | CWHeight, CFG_FORCE_REDRAW);
@@ -754,7 +754,7 @@ clientUpdateFullscreenState (Client * c)
                         frameLeft (c),
                         frameRight (c),
                         frameBottom (c));
-
+    clientSetNetState (c);
 }
 
 void
@@ -1306,8 +1306,8 @@ clientWindowType (Client * c)
     if ((old_type != c->type) || (c->initial_layer != c->win_layer))
     {
         TRACE ("setting layer %i", c->initial_layer);
-        clientSetNetState (c);
         clientSetLayer (c, c->initial_layer);
+        clientSetNetState (c);
     }
 }
 
@@ -1332,8 +1332,8 @@ clientUpdateLayerState (Client * c)
     {
         layer = c->initial_layer;
     }
-    clientSetNetState (c);
     clientSetLayer (c, layer);
+    clientSetNetState (c);
 }
 
 void
@@ -1356,3 +1356,87 @@ clientSetNetActiveWindow (ScreenInfo *screen_info, Client *c, Time timestamp)
                      PropModeReplace, (unsigned char *) data, 2);
 }
 
+static gboolean
+ping_timeout_cb (gpointer data)
+{
+    Client *c;
+
+    TRACE ("entering ping_timeout_cb");
+
+    c = (Client *) data;
+    if (c)
+    {
+        c->ping_timeout_id = 0;
+        TRACE ("Ping timeout on client \"%s\"", c->name);
+        terminateShowDialog (c);
+    }
+    return (FALSE);
+}
+
+void
+clientRemoveNetWMPing (Client *c)
+{
+    g_return_if_fail (c != NULL);
+
+    TRACE ("entering clientSendNetWMPing");
+
+    if (c->ping_timeout_id)
+    {
+        g_source_remove (c->ping_timeout_id);
+    }
+    c->ping_timeout_id = 0;
+    c->ping_time = 0;
+}
+
+void
+clientReceiveNetWMPong (ScreenInfo *screen_info, Time timestamp)
+{
+    Client *c;
+    int i;
+
+    g_return_if_fail (screen_info != NULL);
+    g_return_if_fail (timestamp != CurrentTime);
+
+    TRACE ("entering clientReceiveNetWMPong, timestamp %u", (unsigned int) timestamp);
+
+    for (c = screen_info->clients, i = 0; i < screen_info->client_count; c = c->next, i++)
+    {
+        if (c->ping_time == timestamp)
+        {
+            clientRemoveNetWMPing (c);
+        }
+    }
+}
+
+gboolean
+clientSendNetWMPing (Client *c, Time timestamp)
+{
+    ScreenInfo *screen_info;
+    DisplayInfo *display_info;
+
+    g_return_val_if_fail (c != NULL, FALSE);
+
+    TRACE ("entering clientSendNetWMPing");
+
+    if (!FLAG_TEST (c->wm_flags, WM_FLAG_PING))
+    {
+        return (FALSE);
+    }
+
+    clientRemoveNetWMPing (c);
+
+    screen_info = c->screen_info;
+    display_info = screen_info->display_info;
+
+    /* Makes sure the tiemstamp is meaningfull */
+    c->ping_time = myDisplayGetTime (display_info, timestamp);
+    g_return_val_if_fail (timestamp != CurrentTime, FALSE);
+
+    sendClientMessage (screen_info, c->window, NET_WM_PING, timestamp);
+    c->ping_timeout_id =
+        g_timeout_add_full (G_PRIORITY_DEFAULT,
+                            CLIENT_PING_TIMEOUT,
+                            (GtkFunction) ping_timeout_cb,
+                            (gpointer) c, NULL);
+    return (TRUE);
+}
