@@ -1,4 +1,4 @@
-/*      $Id: netwm.h 27111 2008-06-21 15:17:00Z olivier $
+/*      $Id: netwm.h 27954 2008-09-25 15:40:21Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -53,5 +53,10 @@ void                     clientUpdateLayerState                 (Client *);
 void                     clientSetNetActiveWindow               (ScreenInfo *,
                                                                  Client *,
                                                                  Time);
+void                    clientRemoveNetWMPing                   (Client *);
+gboolean                clientSendNetWMPing                     (Client *,
+                                                                 Time);
+void                    clientReceiveNetWMPong                  (ScreenInfo *,
+                                                                 Time);
 
 #endif /* INC_NETWM_H */
