@@ -1,4 +1,4 @@
-/*      $Id: screen.c 28384 2008-10-23 17:18:16Z olivier $
+/*      $Id: screen.c 27421 2008-08-04 20:28:44Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -12,15 +12,16 @@
 
         You should have received a copy of the GNU General Public License
         along with this program; if not, write to the Free Software
-        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+        Foundation, Inc., Inc., 51 Franklin Street, Fifth Floor, Boston,
+        MA 02110-1301, USA.
 
-        xfwm4    - (c) 2002-2006 Olivier Fourdan
+
+        xfwm4    - (c) 2002-2008 Olivier Fourdan
 
  */
 
-
 #ifdef HAVE_CONFIG_H
-#  include "config.h"
+#include "config.h"
 #endif
 
 #include <X11/Xlib.h>
@@ -85,7 +86,7 @@ myScreenSetWMAtom (ScreenInfo *screen_info, gboolean replace_wm)
     {
         if (!replace_wm)
         {
-            g_message (_("To replace the window manager, try with \"--replace\"\n"));
+            g_message ("To replace the current window manager, try \"--replace\"");
             return FALSE;
         }
         gdk_error_trap_push ();
@@ -99,7 +100,7 @@ myScreenSetWMAtom (ScreenInfo *screen_info, gboolean replace_wm)
 
     if (!setXAtomManagerOwner (display_info, wm_sn_atom, screen_info->xroot, screen_info->xfwm4_win))
     {
-        g_warning (_("Cannot acquire window manager selection on screen %d\n"), screen_info->screen);
+        g_warning ("Cannot acquire window manager selection on screen %d", screen_info->screen);
         return FALSE;
     }
 
@@ -120,7 +121,7 @@ myScreenSetWMAtom (ScreenInfo *screen_info, gboolean replace_wm)
 
         if (wait >= timeout)
         {
-            g_warning(_("Previous window manager on screen %d is not exiting"), screen_info->screen);
+            g_warning("Previous window manager on screen %d is not exiting", screen_info->screen);
             return FALSE;
         }
     }
@@ -130,11 +131,14 @@ myScreenSetWMAtom (ScreenInfo *screen_info, gboolean replace_wm)
 ScreenInfo *
 myScreenInit (DisplayInfo *display_info, GdkScreen *gscr, unsigned long event_mask, gboolean replace_wm)
 {
+#ifdef ENABLE_KDE_SYSTRAY_PROXY
+    gchar selection[32];
+#endif
     ScreenInfo *screen_info;
     GdkWindow *event_win;
     PangoLayout *layout;
     long desktop_visible;
-    int i;
+    int i, j;
 
     g_return_val_if_fail (display_info, NULL);
     g_return_val_if_fail (GDK_IS_SCREEN (gscr), NULL);
@@ -206,9 +210,6 @@ myScreenInit (DisplayInfo *display_info, GdkScreen *gscr, unsigned long event_ma
     screen_info->workspace_names = NULL;
     screen_info->workspace_names_items = 0;
 
-    screen_info->mcs_client = NULL;
-    screen_info->mcs_initted = FALSE;
-
     screen_info->windows_stack = NULL;
     screen_info->last_raise = NULL;
     screen_info->windows = NULL;
@@ -271,6 +272,7 @@ myScreenInit (DisplayInfo *display_info, GdkScreen *gscr, unsigned long event_ma
     screen_info->systray = getSystrayWindow (display_info, screen_info->net_system_tray_selection);
 #endif
 
+    screen_info->font_height = 0;
     screen_info->box_gc = None;
     screen_info->black_gc = NULL;
     screen_info->white_gc = NULL;
@@ -283,29 +285,29 @@ myScreenInit (DisplayInfo *display_info, GdkScreen *gscr, unsigned long event_ma
     screen_info->title_shadow_colors[INACTIVE].gc = NULL;
     screen_info->title_shadow_colors[INACTIVE].allocated = FALSE;
 
-    for (i = 0; i < BUTTON_LAST; i++)
-    {
-        xfwmPixmapInit (screen_info, &screen_info->buttons[i][ACTIVE]);
-        xfwmPixmapInit (screen_info, &screen_info->buttons[i][INACTIVE]);
-        xfwmPixmapInit (screen_info, &screen_info->buttons[i][PRESSED]);
-        xfwmPixmapInit (screen_info, &screen_info->buttons[i][T_ACTIVE]);
-        xfwmPixmapInit (screen_info, &screen_info->buttons[i][T_INACTIVE]);
-        xfwmPixmapInit (screen_info, &screen_info->buttons[i][T_PRESSED]);
-    }
-    for (i = 0; i < 4; i++)
-    {
-        xfwmPixmapInit (screen_info, &screen_info->corners[i][ACTIVE]);
-        xfwmPixmapInit (screen_info, &screen_info->corners[i][INACTIVE]);
-    }
-    for (i = 0; i < 3; i++)
+    for (i = 0; i < SIDE_COUNT; i++)
     {
         xfwmPixmapInit (screen_info, &screen_info->sides[i][ACTIVE]);
         xfwmPixmapInit (screen_info, &screen_info->sides[i][INACTIVE]);
     }
-    for (i = 0; i < 5; i++)
+    for (i = 0; i < CORNER_COUNT; i++)
+    {
+        xfwmPixmapInit (screen_info, &screen_info->corners[i][ACTIVE]);
+        xfwmPixmapInit (screen_info, &screen_info->corners[i][INACTIVE]);
+    }
+    for (i = 0; i < BUTTON_COUNT; i++)
+    {
+        for (j = 0; j < STATE_COUNT; j++)
+        {
+            xfwmPixmapInit (screen_info, &screen_info->buttons[i][j]);
+        }
+    }
+    for (i = 0; i < TITLE_COUNT; i++)
     {
         xfwmPixmapInit (screen_info, &screen_info->title[i][ACTIVE]);
         xfwmPixmapInit (screen_info, &screen_info->title[i][INACTIVE]);
+        xfwmPixmapInit (screen_info, &screen_info->top[i][ACTIVE]);
+        xfwmPixmapInit (screen_info, &screen_info->top[i][INACTIVE]);
     }
 
     return (screen_info);
@@ -385,7 +387,7 @@ myScreenGetGdkWindow (ScreenInfo *screen_info)
 }
 
 gboolean
-myScreenGrabKeyboard (ScreenInfo *screen_info, guint32 time)
+myScreenGrabKeyboard (ScreenInfo *screen_info, Time time)
 {
     gboolean grab;
 
@@ -400,7 +402,7 @@ myScreenGrabKeyboard (ScreenInfo *screen_info, guint32 time)
                                screen_info->xfwm4_win,
                                FALSE,
                                GrabModeAsync, GrabModeAsync,
-                               (Time) time) == GrabSuccess);
+                               time) == GrabSuccess);
     }
     screen_info->key_grabs++;
     TRACE ("global key grabs %i", screen_info->key_grabs);
@@ -409,7 +411,7 @@ myScreenGrabKeyboard (ScreenInfo *screen_info, guint32 time)
 }
 
 gboolean
-myScreenGrabPointer (ScreenInfo *screen_info, unsigned int event_mask, Cursor cursor, guint32 time)
+myScreenGrabPointer (ScreenInfo *screen_info, unsigned int event_mask, Cursor cursor, Time time)
 {
     gboolean grab;
 
@@ -425,7 +427,7 @@ myScreenGrabPointer (ScreenInfo *screen_info, unsigned int event_mask, Cursor cu
                               GrabModeAsync, GrabModeAsync,
                               screen_info->xroot,
                               cursor,
-                              (Time) time) == GrabSuccess);
+                              time) == GrabSuccess);
     }
     screen_info->pointer_grabs++;
     TRACE ("global pointer grabs %i", screen_info->pointer_grabs);
@@ -433,8 +435,26 @@ myScreenGrabPointer (ScreenInfo *screen_info, unsigned int event_mask, Cursor cu
     return grab;
 }
 
+gboolean
+myScreenChangeGrabPointer (ScreenInfo *screen_info, unsigned int event_mask, Cursor cursor, Time time)
+{
+    gboolean grab;
+
+    g_return_val_if_fail (screen_info, FALSE);
+    TRACE ("entering myScreenGrabPointer");
+
+    grab = FALSE;
+    if (screen_info->pointer_grabs > 0)
+    {
+        grab = (XChangeActivePointerGrab (myScreenGetXDisplay (screen_info),
+                                          event_mask, cursor, time) == GrabSuccess);
+    }
+
+    return grab;
+}
+
 unsigned int
-myScreenUngrabKeyboard (ScreenInfo *screen_info)
+myScreenUngrabKeyboard (ScreenInfo *screen_info, Time time)
 {
     g_return_val_if_fail (screen_info, 0);
     TRACE ("entering myScreenUngrabKeyboard");
@@ -446,7 +466,7 @@ myScreenUngrabKeyboard (ScreenInfo *screen_info)
     }
     if (screen_info->key_grabs == 0)
     {
-        XUngrabKeyboard (myScreenGetXDisplay (screen_info), CurrentTime);
+        XUngrabKeyboard (myScreenGetXDisplay (screen_info), time);
     }
     TRACE ("global key grabs %i", screen_info->key_grabs);
 
@@ -454,7 +474,7 @@ myScreenUngrabKeyboard (ScreenInfo *screen_info)
 }
 
 unsigned int
-myScreenUngrabPointer (ScreenInfo *screen_info)
+myScreenUngrabPointer (ScreenInfo *screen_info, Time time)
 {
     g_return_val_if_fail (screen_info, 0);
     TRACE ("entering myScreenUngrabPointer");
@@ -466,7 +486,7 @@ myScreenUngrabPointer (ScreenInfo *screen_info)
     }
     if (screen_info->pointer_grabs == 0)
     {
-        XUngrabPointer (myScreenGetXDisplay (screen_info), CurrentTime);
+        XUngrabPointer (myScreenGetXDisplay (screen_info), time);
     }
     TRACE ("global pointer grabs %i", screen_info->pointer_grabs);
 
@@ -477,71 +497,17 @@ void
 myScreenGrabKeys (ScreenInfo *screen_info)
 {
     Display *dpy;
+    int i;
 
     TRACE ("entering myScreenUnrabKeys");
     g_return_if_fail (screen_info != NULL);
 
     dpy = myScreenGetXDisplay (screen_info);
 
-    grabKey (dpy, &screen_info->params->keys[KEY_ADD_WORKSPACE], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_CLOSE_WINDOW], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_CYCLE_WINDOWS], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_DEL_WORKSPACE], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_DOWN_WORKSPACE], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_HIDE_WINDOW], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_LEFT_WORKSPACE], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_LOWER_WINDOW], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_MAXIMIZE_HORIZ], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_MAXIMIZE_VERT], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_MAXIMIZE_WINDOW], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_MOVE_DOWN], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_MOVE_DOWN_WORKSPACE], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_MOVE_LEFT], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_MOVE_LEFT_WORKSPACE], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_MOVE_NEXT_WORKSPACE], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_MOVE_PREV_WORKSPACE], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_MOVE_RIGHT], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_MOVE_RIGHT_WORKSPACE], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_MOVE_UP], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_MOVE_UP_WORKSPACE], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_MOVE_WORKSPACE_1], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_MOVE_WORKSPACE_2], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_MOVE_WORKSPACE_3], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_MOVE_WORKSPACE_4], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_MOVE_WORKSPACE_5], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_MOVE_WORKSPACE_6], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_MOVE_WORKSPACE_7], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_MOVE_WORKSPACE_8], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_MOVE_WORKSPACE_9], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_MOVE_WORKSPACE_10], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_MOVE_WORKSPACE_11], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_MOVE_WORKSPACE_12], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_NEXT_WORKSPACE], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_POPUP_MENU], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_PREV_WORKSPACE], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_RAISE_WINDOW], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_RESIZE_DOWN], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_RESIZE_LEFT], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_RESIZE_RIGHT], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_RESIZE_UP], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_RIGHT_WORKSPACE], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_SHADE_WINDOW], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_SHOW_DESKTOP], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_STICK_WINDOW], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_TOGGLE_FULLSCREEN], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_UP_WORKSPACE], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_WORKSPACE_1], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_WORKSPACE_2], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_WORKSPACE_3], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_WORKSPACE_4], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_WORKSPACE_5], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_WORKSPACE_6], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_WORKSPACE_7], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_WORKSPACE_8], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_WORKSPACE_9], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_WORKSPACE_10], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_WORKSPACE_11], screen_info->xroot);
-    grabKey (dpy, &screen_info->params->keys[KEY_WORKSPACE_12], screen_info->xroot);
+    for (i = FIRST_KEY; i < KEY_COUNT; i++)
+    {
+        grabKey (dpy, &screen_info->params->keys[i], screen_info->xroot);
+    }
 }
 
 void
@@ -556,3 +522,24 @@ myScreenUngrabKeys (ScreenInfo *screen_info)
     ungrabKeys (dpy, screen_info->xroot);
 }
 
+Client *
+myScreenGetClientFromWindow (ScreenInfo *screen_info, Window w, unsigned short mode)
+{
+    Client *c;
+    int i;
+
+    g_return_val_if_fail (w != None, NULL);
+    TRACE ("entering myScreenGetClientFromWindow");
+    TRACE ("looking for (0x%lx)", w);
+
+    for (c = screen_info->clients, i = 0; i < screen_info->client_count; c = c->next, i++)
+    {
+        if (clientGetFromWindow (c, w, mode))
+        {
+            return (c);
+        }
+    }
+    TRACE ("no client found");
+
+    return NULL;
+}
