@@ -1,4 +1,4 @@
-/*      $Id: screen.h 28384 2008-10-23 17:18:16Z olivier $
+/*      $Id: screen.h 27451 2008-08-14 22:36:35Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -12,22 +12,24 @@
 
         You should have received a copy of the GNU General Public License
         along with this program; if not, write to the Free Software
-        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+        Foundation, Inc., Inc., 51 Franklin Street, Fifth Floor, Boston,
+        MA 02110-1301, USA.
+
 
         oroborus - (c) 2001 Ken Lynch
-        xfwm4    - (c) 2002-2006 Olivier Fourdan
+        xfwm4    - (c) 2002-2008 Olivier Fourdan
 
  */
 
 #ifdef HAVE_CONFIG_H
-#  include "config.h"
+#include "config.h"
 #endif
 
 #include <X11/Xlib.h>
 #include <X11/cursorfont.h>
 #include <gtk/gtk.h>
 #include <glib.h>
-#include <libxfce4mcs/mcs-client.h>
+#include <xfconf/xfconf.h>
 
 #ifdef HAVE_LIBSTARTUP_NOTIFICATION
 #define SN_API_NOT_YET_FROZEN
@@ -70,16 +72,20 @@ struct _ScreenInfo
     /* Theme pixmaps and other params, per screen */
     XfwmColor title_colors[2];
     XfwmColor title_shadow_colors[2];
-    xfwmPixmap buttons[BUTTON_COUNT][6];
-    xfwmPixmap corners[4][2];
-    xfwmPixmap sides[3][2];
-    xfwmPixmap title[5][2];
+    xfwmPixmap buttons[BUTTON_COUNT][STATE_COUNT];
+    xfwmPixmap corners[CORNER_COUNT][2];
+    xfwmPixmap sides[SIDE_COUNT][2];
+    xfwmPixmap title[TITLE_COUNT][2];
+    xfwmPixmap top[TITLE_COUNT][2];
 
     /* Per screen graphic contexts */
     GC box_gc;
     GdkGC *black_gc;
     GdkGC *white_gc;
 
+    /* Title font height */
+    int font_height;
+
     /* Screen data */
     Colormap cmap;
     GdkScreen *gscr;
@@ -109,9 +115,9 @@ struct _ScreenInfo
     /* Button handler for GTK */
     gulong button_handler_id;
 
-    /* MCS stuff */
-    McsClient *mcs_client;
-    gboolean mcs_initted;
+    /* xfconf */
+    XfconfChannel *xfwm4_channel;
+    XfconfChannel *keys_channel;
 
     /* Per screen parameters */
     XfwmParams *params;
@@ -140,7 +146,6 @@ struct _ScreenInfo
     GList *cwindows;
     Window output;
 
-
     gaussian_conv *gaussianMap;
     gint gaussianSize;
     guchar *shadowCorner;
@@ -155,6 +160,10 @@ struct _ScreenInfo
     guint wins_unredirected;
     gboolean compositor_active;
     gboolean clipChanged;
+
+    gboolean damages_pending;
+
+    guint compositor_timeout_id;
 #endif /* HAVE_COMPOSITOR */
 };
 
@@ -170,13 +179,23 @@ GtkWidget               *myScreenGetGtkWidget                   (ScreenInfo *);
 GtkWidget               *myScreenGetGtkWidget                   (ScreenInfo *);
 GdkWindow               *myScreenGetGdkWindow                   (ScreenInfo *);
 gboolean                 myScreenGrabKeyboard                   (ScreenInfo *,
-                                                                 guint32);
+                                                                 Time);
 gboolean                 myScreenGrabPointer                    (ScreenInfo *,
                                                                  unsigned int,
                                                                  Cursor,
-                                                                 guint32);
-unsigned int             myScreenUngrabKeyboard                 (ScreenInfo *);
-unsigned int             myScreenUngrabPointer                  (ScreenInfo *);
+                                                                 Time);
+gboolean                 myScreenChangeGrabPointer              (ScreenInfo *,
+                                                                 unsigned int,
+                                                                 Cursor,
+                                                                 Time);
+unsigned int             myScreenUngrabKeyboard                 (ScreenInfo *,
+                                                                 Time);
+unsigned int             myScreenUngrabPointer                  (ScreenInfo *,
+                                                                 Time);
 void                     myScreenGrabKeys                       (ScreenInfo *);
 void                     myScreenUngrabKeys                     (ScreenInfo *);
+Client                  *myScreenGetClientFromWindow            (ScreenInfo *,
+                                                                 Window,
+                                                                 unsigned short);
+
 #endif /* INC_SCREEN_H */
