@@ -1,4 +1,4 @@
-/*      $Id: startup_notification.c 28362 2008-10-22 19:58:39Z olivier $
+/*      $Id: startup_notification.c 26999 2008-05-31 14:35:42Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -12,15 +12,17 @@
 
         You should have received a copy of the GNU General Public License
         along with this program; if not, write to the Free Software
-        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+        Foundation, Inc., Inc., 51 Franklin Street, Fifth Floor, Boston,
+        MA 02110-1301, USA.
+
 
         Metacity - (c) 2003 Havoc Pennington
-        xfwm4    - (c) 2002-2006 Olivier Fourdan
+        xfwm4    - (c) 2002-2008 Olivier Fourdan
 
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #ifdef HAVE_LIBSTARTUP_NOTIFICATION
@@ -280,15 +282,18 @@ sn_client_startup_properties (Client * c)
     if (sequence != NULL)
     {
         int workspace;
-        guint32 timestamp;
+        Time timestamp;
 
         /* Set initial time */
         timestamp = sn_startup_sequence_get_timestamp (sequence);
         TRACE ("Given startup time: %u", (unsigned int) timestamp);
-        if ((c->user_time == 0) || TIMESTAMP_IS_BEFORE(c->user_time, timestamp))
+        if ((c->user_time == (Time) 0) || TIMESTAMP_IS_BEFORE(c->user_time, timestamp))
         {
             c->user_time = timestamp;
-            myDisplaySetLastUserTime (screen_info->display_info, c->user_time);
+            if (c->user_time != (Time) 0)
+            {
+                myDisplayUpdateLastUserTime (screen_info->display_info, c->user_time);
+            }
         }
         FLAG_SET (c->flags, CLIENT_FLAG_HAS_STARTUP_TIME);
 
